# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# From type library 'ksConstants3D.tlb'
# On Fri Nov  5 08:15:10 2021
''
makepy_version = '0.5.01'
python_version = 0x30802f0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{2CAF168C-7961-4B90-9DA2-701419BEEFE3}')
MajorVersion = 1
MinorVersion = 0
LibraryFlags = 8
LCID = 0x0

class constants:
	format_C3D                    =7          # from enum D3FormatConvType
	format_IGES                   =4          # from enum D3FormatConvType
	format_JT                     =8          # from enum D3FormatConvType
	format_SAT                    =1          # from enum D3FormatConvType
	format_STEP                   =3          # from enum D3FormatConvType
	format_STEP_AP203             =203        # from enum D3FormatConvType
	format_STEP_AP214             =214        # from enum D3FormatConvType
	format_STEP_AP242             =242        # from enum D3FormatConvType
	format_STL                    =6          # from enum D3FormatConvType
	format_Unknown                =0          # from enum D3FormatConvType
	format_VRML                   =5          # from enum D3FormatConvType
	format_XT                     =2          # from enum D3FormatConvType
	load_format_C3D               =-7         # from enum D3FormatConvType
	load_format_CATIA             =-104       # from enum D3FormatConvType
	load_format_CREO              =-101       # from enum D3FormatConvType
	load_format_IGES              =-4         # from enum D3FormatConvType
	load_format_INV               =-103       # from enum D3FormatConvType
	load_format_JT                =-8         # from enum D3FormatConvType
	load_format_NX                =-100       # from enum D3FormatConvType
	load_format_SAT               =-1         # from enum D3FormatConvType
	load_format_SE                =-105       # from enum D3FormatConvType
	load_format_STEP              =-3         # from enum D3FormatConvType
	load_format_STL               =-6         # from enum D3FormatConvType
	load_format_SW                =-102       # from enum D3FormatConvType
	load_format_XT                =-2         # from enum D3FormatConvType
	dtBoth                        =2          # from enum Direction_Type
	dtMiddlePlane                 =3          # from enum Direction_Type
	dtNormal                      =0          # from enum Direction_Type
	dtReverse                     =1          # from enum Direction_Type
	etBlind                       =0          # from enum End_Type
	etThroughAll                  =1          # from enum End_Type
	etUpToNearSurface             =6          # from enum End_Type
	etUpToSurfaceFrom             =5          # from enum End_Type
	etUpToSurfaceTo               =4          # from enum End_Type
	etUpToVertexFrom              =3          # from enum End_Type
	etUpToVertexTo                =2          # from enum End_Type
	et3dAbort                     =-1         # from enum ErrorType3d
	et3dError1                    =1          # from enum ErrorType3d
	et3dError10                   =10         # from enum ErrorType3d
	et3dError100                  =100        # from enum ErrorType3d
	et3dError101                  =101        # from enum ErrorType3d
	et3dError102                  =102        # from enum ErrorType3d
	et3dError103                  =103        # from enum ErrorType3d
	et3dError104                  =104        # from enum ErrorType3d
	et3dError105                  =105        # from enum ErrorType3d
	et3dError106                  =106        # from enum ErrorType3d
	et3dError107                  =107        # from enum ErrorType3d
	et3dError108                  =108        # from enum ErrorType3d
	et3dError109                  =109        # from enum ErrorType3d
	et3dError11                   =11         # from enum ErrorType3d
	et3dError110                  =110        # from enum ErrorType3d
	et3dError111                  =111        # from enum ErrorType3d
	et3dError112                  =112        # from enum ErrorType3d
	et3dError113                  =113        # from enum ErrorType3d
	et3dError114                  =114        # from enum ErrorType3d
	et3dError115                  =115        # from enum ErrorType3d
	et3dError116                  =116        # from enum ErrorType3d
	et3dError117                  =117        # from enum ErrorType3d
	et3dError118                  =118        # from enum ErrorType3d
	et3dError119                  =119        # from enum ErrorType3d
	et3dError12                   =12         # from enum ErrorType3d
	et3dError120                  =120        # from enum ErrorType3d
	et3dError121                  =121        # from enum ErrorType3d
	et3dError122                  =122        # from enum ErrorType3d
	et3dError123                  =123        # from enum ErrorType3d
	et3dError124                  =124        # from enum ErrorType3d
	et3dError125                  =125        # from enum ErrorType3d
	et3dError126                  =126        # from enum ErrorType3d
	et3dError127                  =127        # from enum ErrorType3d
	et3dError128                  =128        # from enum ErrorType3d
	et3dError129                  =129        # from enum ErrorType3d
	et3dError13                   =13         # from enum ErrorType3d
	et3dError130                  =130        # from enum ErrorType3d
	et3dError131                  =131        # from enum ErrorType3d
	et3dError132                  =132        # from enum ErrorType3d
	et3dError133                  =133        # from enum ErrorType3d
	et3dError134                  =134        # from enum ErrorType3d
	et3dError135                  =135        # from enum ErrorType3d
	et3dError136                  =136        # from enum ErrorType3d
	et3dError137                  =137        # from enum ErrorType3d
	et3dError138                  =138        # from enum ErrorType3d
	et3dError139                  =139        # from enum ErrorType3d
	et3dError14                   =14         # from enum ErrorType3d
	et3dError140                  =140        # from enum ErrorType3d
	et3dError141                  =141        # from enum ErrorType3d
	et3dError142                  =142        # from enum ErrorType3d
	et3dError143                  =143        # from enum ErrorType3d
	et3dError144                  =144        # from enum ErrorType3d
	et3dError145                  =145        # from enum ErrorType3d
	et3dError146                  =146        # from enum ErrorType3d
	et3dError147                  =147        # from enum ErrorType3d
	et3dError148                  =148        # from enum ErrorType3d
	et3dError149                  =149        # from enum ErrorType3d
	et3dError15                   =15         # from enum ErrorType3d
	et3dError150                  =150        # from enum ErrorType3d
	et3dError151                  =151        # from enum ErrorType3d
	et3dError152                  =152        # from enum ErrorType3d
	et3dError153                  =153        # from enum ErrorType3d
	et3dError154                  =154        # from enum ErrorType3d
	et3dError155                  =155        # from enum ErrorType3d
	et3dError156                  =156        # from enum ErrorType3d
	et3dError157                  =157        # from enum ErrorType3d
	et3dError158                  =158        # from enum ErrorType3d
	et3dError159                  =159        # from enum ErrorType3d
	et3dError16                   =16         # from enum ErrorType3d
	et3dError160                  =160        # from enum ErrorType3d
	et3dError161                  =161        # from enum ErrorType3d
	et3dError162                  =162        # from enum ErrorType3d
	et3dError163                  =163        # from enum ErrorType3d
	et3dError164                  =164        # from enum ErrorType3d
	et3dError165                  =165        # from enum ErrorType3d
	et3dError166                  =166        # from enum ErrorType3d
	et3dError167                  =167        # from enum ErrorType3d
	et3dError168                  =168        # from enum ErrorType3d
	et3dError169                  =169        # from enum ErrorType3d
	et3dError17                   =17         # from enum ErrorType3d
	et3dError170                  =170        # from enum ErrorType3d
	et3dError171                  =171        # from enum ErrorType3d
	et3dError172                  =172        # from enum ErrorType3d
	et3dError173                  =173        # from enum ErrorType3d
	et3dError174                  =174        # from enum ErrorType3d
	et3dError175                  =175        # from enum ErrorType3d
	et3dError176                  =176        # from enum ErrorType3d
	et3dError177                  =177        # from enum ErrorType3d
	et3dError179                  =179        # from enum ErrorType3d
	et3dError18                   =18         # from enum ErrorType3d
	et3dError180                  =180        # from enum ErrorType3d
	et3dError181                  =181        # from enum ErrorType3d
	et3dError182                  =182        # from enum ErrorType3d
	et3dError183                  =183        # from enum ErrorType3d
	et3dError184                  =184        # from enum ErrorType3d
	et3dError185                  =185        # from enum ErrorType3d
	et3dError186                  =186        # from enum ErrorType3d
	et3dError187                  =187        # from enum ErrorType3d
	et3dError188                  =188        # from enum ErrorType3d
	et3dError189                  =189        # from enum ErrorType3d
	et3dError19                   =19         # from enum ErrorType3d
	et3dError190                  =190        # from enum ErrorType3d
	et3dError191                  =191        # from enum ErrorType3d
	et3dError192                  =192        # from enum ErrorType3d
	et3dError193                  =193        # from enum ErrorType3d
	et3dError194                  =194        # from enum ErrorType3d
	et3dError195                  =195        # from enum ErrorType3d
	et3dError196                  =196        # from enum ErrorType3d
	et3dError197                  =197        # from enum ErrorType3d
	et3dError2                    =2          # from enum ErrorType3d
	et3dError20                   =20         # from enum ErrorType3d
	et3dError21                   =21         # from enum ErrorType3d
	et3dError22                   =22         # from enum ErrorType3d
	et3dError23                   =23         # from enum ErrorType3d
	et3dError24                   =24         # from enum ErrorType3d
	et3dError25                   =25         # from enum ErrorType3d
	et3dError26                   =26         # from enum ErrorType3d
	et3dError27                   =27         # from enum ErrorType3d
	et3dError28                   =28         # from enum ErrorType3d
	et3dError29                   =29         # from enum ErrorType3d
	et3dError3                    =3          # from enum ErrorType3d
	et3dError30                   =30         # from enum ErrorType3d
	et3dError31                   =31         # from enum ErrorType3d
	et3dError32                   =32         # from enum ErrorType3d
	et3dError33                   =33         # from enum ErrorType3d
	et3dError34                   =34         # from enum ErrorType3d
	et3dError35                   =35         # from enum ErrorType3d
	et3dError36                   =36         # from enum ErrorType3d
	et3dError37                   =37         # from enum ErrorType3d
	et3dError38                   =38         # from enum ErrorType3d
	et3dError39                   =39         # from enum ErrorType3d
	et3dError4                    =4          # from enum ErrorType3d
	et3dError40                   =40         # from enum ErrorType3d
	et3dError41                   =41         # from enum ErrorType3d
	et3dError42                   =42         # from enum ErrorType3d
	et3dError43                   =43         # from enum ErrorType3d
	et3dError44                   =44         # from enum ErrorType3d
	et3dError45                   =45         # from enum ErrorType3d
	et3dError46                   =46         # from enum ErrorType3d
	et3dError47                   =47         # from enum ErrorType3d
	et3dError48                   =48         # from enum ErrorType3d
	et3dError49                   =49         # from enum ErrorType3d
	et3dError5                    =5          # from enum ErrorType3d
	et3dError50                   =50         # from enum ErrorType3d
	et3dError51                   =51         # from enum ErrorType3d
	et3dError52                   =52         # from enum ErrorType3d
	et3dError53                   =53         # from enum ErrorType3d
	et3dError54                   =54         # from enum ErrorType3d
	et3dError55                   =55         # from enum ErrorType3d
	et3dError56                   =56         # from enum ErrorType3d
	et3dError57                   =57         # from enum ErrorType3d
	et3dError58                   =58         # from enum ErrorType3d
	et3dError59                   =59         # from enum ErrorType3d
	et3dError6                    =6          # from enum ErrorType3d
	et3dError60                   =60         # from enum ErrorType3d
	et3dError61                   =61         # from enum ErrorType3d
	et3dError62                   =62         # from enum ErrorType3d
	et3dError63                   =63         # from enum ErrorType3d
	et3dError64                   =64         # from enum ErrorType3d
	et3dError65                   =65         # from enum ErrorType3d
	et3dError66                   =66         # from enum ErrorType3d
	et3dError67                   =67         # from enum ErrorType3d
	et3dError68                   =68         # from enum ErrorType3d
	et3dError69                   =69         # from enum ErrorType3d
	et3dError7                    =7          # from enum ErrorType3d
	et3dError70                   =70         # from enum ErrorType3d
	et3dError71                   =71         # from enum ErrorType3d
	et3dError72                   =72         # from enum ErrorType3d
	et3dError73                   =73         # from enum ErrorType3d
	et3dError74                   =74         # from enum ErrorType3d
	et3dError75                   =75         # from enum ErrorType3d
	et3dError76                   =76         # from enum ErrorType3d
	et3dError77                   =77         # from enum ErrorType3d
	et3dError78                   =78         # from enum ErrorType3d
	et3dError79                   =79         # from enum ErrorType3d
	et3dError8                    =8          # from enum ErrorType3d
	et3dError80                   =80         # from enum ErrorType3d
	et3dError81                   =81         # from enum ErrorType3d
	et3dError82                   =82         # from enum ErrorType3d
	et3dError83                   =83         # from enum ErrorType3d
	et3dError84                   =84         # from enum ErrorType3d
	et3dError85                   =85         # from enum ErrorType3d
	et3dError86                   =86         # from enum ErrorType3d
	et3dError87                   =87         # from enum ErrorType3d
	et3dError88                   =88         # from enum ErrorType3d
	et3dError89                   =89         # from enum ErrorType3d
	et3dError9                    =9          # from enum ErrorType3d
	et3dError90                   =90         # from enum ErrorType3d
	et3dError91                   =91         # from enum ErrorType3d
	et3dError92                   =92         # from enum ErrorType3d
	et3dError93                   =93         # from enum ErrorType3d
	et3dError94                   =94         # from enum ErrorType3d
	et3dError95                   =95         # from enum ErrorType3d
	et3dError96                   =96         # from enum ErrorType3d
	et3dError97                   =97         # from enum ErrorType3d
	et3dError98                   =98         # from enum ErrorType3d
	et3dError99                   =99         # from enum ErrorType3d
	et3dNo3dDocument              =-7         # from enum ErrorType3d
	itBody                        =4          # from enum Intersection_Type
	itTangentCurve                =2          # from enum Intersection_Type
	itTangentPoint                =1          # from enum Intersection_Type
	itTangentSurface              =3          # from enum Intersection_Type
	mc_Angle                      =6          # from enum MateConstraintType
	mc_CamGear                    =10         # from enum MateConstraintType
	mc_Coincidence                =0          # from enum MateConstraintType
	mc_Concentric                 =4          # from enum MateConstraintType
	mc_Dependent                  =14         # from enum MateConstraintType
	mc_Distance                   =5          # from enum MateConstraintType
	mc_InPlace                    =7          # from enum MateConstraintType
	mc_Parallel                   =1          # from enum MateConstraintType
	mc_Perpendicular              =2          # from enum MateConstraintType
	mc_Symmetric                  =11         # from enum MateConstraintType
	mc_Tangency                   =3          # from enum MateConstraintType
	mc_Transmission               =9          # from enum MateConstraintType
	mc_Unknown                    =-1         # from enum MateConstraintType
	o3d_AngularUnhistoriedDimension=598        # from enum Obj3dType
	o3d_Arc3D                     =519        # from enum Obj3dType
	o3d_ArcDimension3D            =629        # from enum Obj3dType
	o3d_AreaMeasure               =558        # from enum Obj3dType
	o3d_ArrayExemplar             =549        # from enum Obj3dType
	o3d_AuxCircularCopy           =505        # from enum Obj3dType
	o3d_AuxCurveCopy              =506        # from enum Obj3dType
	o3d_AuxGeomArrayExemplar      =550        # from enum Obj3dType
	o3d_AuxMeshCopy               =504        # from enum Obj3dType
	o3d_AuxMirrorOperation        =509        # from enum Obj3dType
	o3d_AuxPointDrivenPattern     =520        # from enum Obj3dType
	o3d_AuxTablePattern           =524        # from enum Obj3dType
	o3d_AxisFromPointByDirection  =559        # from enum Obj3dType
	o3d_Billet                    =571        # from enum Obj3dType
	o3d_BodiesCircularCopy        =529        # from enum Obj3dType
	o3d_BodiesCurveCopy           =530        # from enum Obj3dType
	o3d_BodiesMeshCopy            =528        # from enum Obj3dType
	o3d_BodiesPointDrivenPattern  =521        # from enum Obj3dType
	o3d_BodiesTablePattern        =525        # from enum Obj3dType
	o3d_BodyArrayExemplar         =551        # from enum Obj3dType
	o3d_BodyReposition            =569        # from enum Obj3dType
	o3d_CircularPatternAnyCopy    =592        # from enum Obj3dType
	o3d_CloudPointsSurface        =527        # from enum Obj3dType
	o3d_CollectionGeometry        =590        # from enum Obj3dType
	o3d_CollisionObject           =622        # from enum Obj3dType
	o3d_ConicSectionSurface       =635        # from enum Obj3dType
	o3d_ConnectCurve              =510        # from enum Obj3dType
	o3d_ConnectCurveObject        =511        # from enum Obj3dType
	o3d_ContinuityCheck           =624        # from enum Obj3dType
	o3d_Contour3D                 =568        # from enum Obj3dType
	o3d_CopyGeometry              =589        # from enum Obj3dType
	o3d_CurvatureCheckObject      =623        # from enum Obj3dType
	o3d_CurvatureGraph            =621        # from enum Obj3dType
	o3d_Curve3DWithoutHistory     =560        # from enum Obj3dType
	o3d_CurveBy2Projections       =561        # from enum Obj3dType
	o3d_CurveByLaw                =562        # from enum Obj3dType
	o3d_CurveOutLine              =564        # from enum Obj3dType
	o3d_CurvePatternAnyCopy       =593        # from enum Obj3dType
	o3d_DiametralUnhistoriedDimension=600        # from enum Obj3dType
	o3d_DistanceAngleMeasure      =556        # from enum Obj3dType
	o3d_DynamicCrossSection       =619        # from enum Obj3dType
	o3d_EdgeLengthMeasure         =557        # from enum Obj3dType
	o3d_Embodiment                =164        # from enum Obj3dType
	o3d_Equidistant3D             =501        # from enum Obj3dType
	o3d_EquidistantSurface        =514        # from enum Obj3dType
	o3d_EvolutionSurface          =59         # from enum Obj3dType
	o3d_ExtensionSurface          =517        # from enum Obj3dType
	o3d_ExtrusionSurface          =60         # from enum Obj3dType
	o3d_FaceLift                  =601        # from enum Obj3dType
	o3d_FaceMover                 =632        # from enum Obj3dType
	o3d_FaceRemover               =95         # from enum Obj3dType
	o3d_FilletCurve               =512        # from enum Obj3dType
	o3d_FilletCurveObject         =513        # from enum Obj3dType
	o3d_FullFillet                =618        # from enum Obj3dType
	o3d_Hole3D                    =583        # from enum Obj3dType
	o3d_IsoparametricCurve        =563        # from enum Obj3dType
	o3d_IsoparametricCurvesSet    =566        # from enum Obj3dType
	o3d_JointSurface              =555        # from enum Obj3dType
	o3d_LineSegment3D             =570        # from enum Obj3dType
	o3d_LinearUnhistoriedDimension=597        # from enum Obj3dType
	o3d_LoftSurface               =62         # from enum Obj3dType
	o3d_MacroObject               =63         # from enum Obj3dType
	o3d_MeshObject3D              =613        # from enum Obj3dType
	o3d_MeshPatternAnyCopy        =591        # from enum Obj3dType
	o3d_MeshPointsSurface         =526        # from enum Obj3dType
	o3d_MirrorPart                =532        # from enum Obj3dType
	o3d_MoldCavity                =65         # from enum Obj3dType
	o3d_NurbsSurface              =97         # from enum Obj3dType
	o3d_NurbsSurfaceByCurvesMesh  =552        # from enum Obj3dType
	o3d_ObjectsFilter3D           =155        # from enum Obj3dType
	o3d_OperationAngularDimension =574        # from enum Obj3dType
	o3d_OperationDiametralDimension=576        # from enum Obj3dType
	o3d_OperationLeaderDimension  =617        # from enum Obj3dType
	o3d_OperationLinearDimension  =573        # from enum Obj3dType
	o3d_OperationRadialDimension  =575        # from enum Obj3dType
	o3d_PartsPointDrivenPattern   =508        # from enum Obj3dType
	o3d_PartsTablePattern         =523        # from enum Obj3dType
	o3d_PlaneByPlaneCurve         =554        # from enum Obj3dType
	o3d_PlaneByPointAndTangentToFace=553        # from enum Obj3dType
	o3d_PointDrivenPattern        =507        # from enum Obj3dType
	o3d_PointDrivenPatternAnyCopy =595        # from enum Obj3dType
	o3d_PointsArrFromFile         =547        # from enum Obj3dType
	o3d_PointsArrOnCurve          =546        # from enum Obj3dType
	o3d_PointsArrOnSurface        =548        # from enum Obj3dType
	o3d_PolyLine3DPoint           =572        # from enum Obj3dType
	o3d_PolygonalLineVertexParam  =158        # from enum Obj3dType
	o3d_ProjectionCurve           =567        # from enum Obj3dType
	o3d_RadialUnhistoriedDimension=599        # from enum Obj3dType
	o3d_RestoredSurface           =620        # from enum Obj3dType
	o3d_RotatedSurface            =61         # from enum Obj3dType
	o3d_RuledSurface              =515        # from enum Obj3dType
	o3d_Scaling3D                 =531        # from enum Obj3dType
	o3d_SectionAnalysis           =626        # from enum Obj3dType
	o3d_SketchAngularDimension    =578        # from enum Obj3dType
	o3d_SketchArcDimension        =628        # from enum Obj3dType
	o3d_SketchBreakAngularDimension=579        # from enum Obj3dType
	o3d_SketchBreakLinearDimension=605        # from enum Obj3dType
	o3d_SketchBreakRadialDimension=581        # from enum Obj3dType
	o3d_SketchDiametralDimension  =582        # from enum Obj3dType
	o3d_SketchFace                =625        # from enum Obj3dType
	o3d_SketchLinearDimension     =577        # from enum Obj3dType
	o3d_SketchRadialDimension     =580        # from enum Obj3dType
	o3d_SpecRough3D               =604        # from enum Obj3dType
	o3d_SplineFormOperation       =608        # from enum Obj3dType
	o3d_SplineOnSurface           =565        # from enum Obj3dType
	o3d_SplitLine                 =93         # from enum Obj3dType
	o3d_SplitSolid                =633        # from enum Obj3dType
	o3d_SubFoldLine               =616        # from enum Obj3dType
	o3d_SurfacePatch              =94         # from enum Obj3dType
	o3d_SurfaceSewer              =96         # from enum Obj3dType
	o3d_SurfaceThickening         =518        # from enum Obj3dType
	o3d_SurfacesIntersectionCurve =98         # from enum Obj3dType
	o3d_TablePattern              =522        # from enum Obj3dType
	o3d_TablePatternAnyCopy       =596        # from enum Obj3dType
	o3d_Text3D                    =627        # from enum Obj3dType
	o3d_TrimmedCurve              =502        # from enum Obj3dType
	o3d_TrimmedCurveObject        =503        # from enum Obj3dType
	o3d_TrimmedSurface            =516        # from enum Obj3dType
	o3d_UnHistoried               =79         # from enum Obj3dType
	o3d_UndefPartObject           =603        # from enum Obj3dType
	o3d_UnhistoriedBase3D         =609        # from enum Obj3dType
	o3d_UnhistoriedThread         =610        # from enum Obj3dType
	o3d_UnionComponents           =64         # from enum Obj3dType
	o3d_UserDesignationCompObj    =611        # from enum Obj3dType
	o3d_UserDesignationObject3D   =607        # from enum Obj3dType
	o3d_UserFolder                =612        # from enum Obj3dType
	o3d_UserObjectOperation       =584        # from enum Obj3dType
	o3d_UserWireFrame3D           =602        # from enum Obj3dType
	o3d_WireFrame3D               =588        # from enum Obj3dType
	o3d_Zone3D                    =585        # from enum Obj3dType
	o3d_Zone3DDivision            =586        # from enum Obj3dType
	o3d_Zones3D                   =587        # from enum Obj3dType
	o3d_additionFormat            =113        # from enum Obj3dType
	o3d_aggregate                 =69         # from enum Obj3dType
	o3d_angleDimension3D          =84         # from enum Obj3dType
	o3d_arc3dParam                =147        # from enum Obj3dType
	o3d_attribute                 =151        # from enum Obj3dType
	o3d_attributeCollection       =152        # from enum Obj3dType
	o3d_axis2Planes               =9          # from enum Obj3dType
	o3d_axis2Points               =10         # from enum Obj3dType
	o3d_axis3D                    =615        # from enum Obj3dType
	o3d_axisConeFace              =11         # from enum Obj3dType
	o3d_axisEdge                  =12         # from enum Obj3dType
	o3d_axisOX                    =71         # from enum Obj3dType
	o3d_axisOY                    =72         # from enum Obj3dType
	o3d_axisOZ                    =73         # from enum Obj3dType
	o3d_axisOperation             =13         # from enum Obj3dType
	o3d_base3D                    =91         # from enum Obj3dType
	o3d_baseEvolution             =45         # from enum Obj3dType
	o3d_baseExtrusion             =24         # from enum Obj3dType
	o3d_baseLoft                  =30         # from enum Obj3dType
	o3d_baseRotated               =27         # from enum Obj3dType
	o3d_baselineDimension3D       =80         # from enum Obj3dType
	o3d_body                      =115        # from enum Obj3dType
	o3d_bodyCollection            =114        # from enum Obj3dType
	o3d_bossEvolution             =46         # from enum Obj3dType
	o3d_bossExtrusion             =25         # from enum Obj3dType
	o3d_bossLoft                  =31         # from enum Obj3dType
	o3d_bossRotated               =28         # from enum Obj3dType
	o3d_brandLeader3D             =90         # from enum Obj3dType
	o3d_chamfer                   =33         # from enum Obj3dType
	o3d_chooseMng                 =146        # from enum Obj3dType
	o3d_circPartArray             =38         # from enum Obj3dType
	o3d_circle3dParam             =130        # from enum Obj3dType
	o3d_circularCopy              =36         # from enum Obj3dType
	o3d_componentPositioner       =153        # from enum Obj3dType
	o3d_coneParam                 =138        # from enum Obj3dType
	o3d_conicSpiral               =54         # from enum Obj3dType
	o3d_conjunctivePoint          =68         # from enum Obj3dType
	o3d_constrElement             =109        # from enum Obj3dType
	o3d_controlPoint              =67         # from enum Obj3dType
	o3d_coordinate3dCollection    =156        # from enum Obj3dType
	o3d_copyleftObject            =163        # from enum Obj3dType
	o3d_curve3D                   =126        # from enum Obj3dType
	o3d_curveCopy                 =37         # from enum Obj3dType
	o3d_curveElement              =111        # from enum Obj3dType
	o3d_curvePartArray            =40         # from enum Obj3dType
	o3d_cutByPlane                =50         # from enum Obj3dType
	o3d_cutBySketch               =51         # from enum Obj3dType
	o3d_cutEvolution              =47         # from enum Obj3dType
	o3d_cutExtrusion              =26         # from enum Obj3dType
	o3d_cutLoft                   =32         # from enum Obj3dType
	o3d_cutRotated                =29         # from enum Obj3dType
	o3d_cylinderParam             =139        # from enum Obj3dType
	o3d_cylindricSpiral           =56         # from enum Obj3dType
	o3d_deletedCopyCollection     =148        # from enum Obj3dType
	o3d_derivPartArray            =41         # from enum Obj3dType
	o3d_designationElement        =162        # from enum Obj3dType
	o3d_diametralDimension3D      =83         # from enum Obj3dType
	o3d_document                  =103        # from enum Obj3dType
	o3d_edge                      =7          # from enum Obj3dType
	o3d_edgeCollection            =121        # from enum Obj3dType
	o3d_ellipse3dParam            =131        # from enum Obj3dType
	o3d_entity                    =105        # from enum Obj3dType
	o3d_entityCollection          =102        # from enum Obj3dType
	o3d_face                      =6          # from enum Obj3dType
	o3d_faceCollection            =116        # from enum Obj3dType
	o3d_facet                     =118        # from enum Obj3dType
	o3d_feature                   =120        # from enum Obj3dType
	o3d_featureCollection         =119        # from enum Obj3dType
	o3d_fillet                    =34         # from enum Obj3dType
	o3d_firstEntityElement2       =500        # from enum Obj3dType
	o3d_holeOperation             =52         # from enum Obj3dType
	o3d_importedSurface           =57         # from enum Obj3dType
	o3d_incline                   =42         # from enum Obj3dType
	o3d_intersectionResult        =157        # from enum Obj3dType
	o3d_intervalVariable          =166        # from enum Obj3dType
	o3d_lastEntityElement         =99         # from enum Obj3dType
	o3d_lastEntityElement2        =1500       # from enum Obj3dType
	o3d_leader3D                  =86         # from enum Obj3dType
	o3d_lineDimension3D           =81         # from enum Obj3dType
	o3d_lineseg3dParam            =129        # from enum Obj3dType
	o3d_localCoordinateSystem     =85         # from enum Obj3dType
	o3d_loop                      =124        # from enum Obj3dType
	o3d_loopCollection            =125        # from enum Obj3dType
	o3d_markLeader3D              =87         # from enum Obj3dType
	o3d_massInertiaParam          =128        # from enum Obj3dType
	o3d_mateConstraint            =106        # from enum Obj3dType
	o3d_mateConstraintCollection  =107        # from enum Obj3dType
	o3d_mateConstraintGroup       =143        # from enum Obj3dType
	o3d_measurer                  =144        # from enum Obj3dType
	o3d_meshCopy                  =35         # from enum Obj3dType
	o3d_meshPartArray             =39         # from enum Obj3dType
	o3d_mirrorAllOperation        =49         # from enum Obj3dType
	o3d_mirrorOperation           =48         # from enum Obj3dType
	o3d_modelLibrary              =154        # from enum Obj3dType
	o3d_nurbs3dParam              =136        # from enum Obj3dType
	o3d_nurbsKnotCollection       =135        # from enum Obj3dType
	o3d_nurbsPoint3dCollCollection=134        # from enum Obj3dType
	o3d_nurbsPoint3dCollection    =133        # from enum Obj3dType
	o3d_nurbsPoint3dParam         =132        # from enum Obj3dType
	o3d_nurbsSurfaceParam         =142        # from enum Obj3dType
	o3d_operationElement          =110        # from enum Obj3dType
	o3d_orientedEdge              =122        # from enum Obj3dType
	o3d_orientedEdgeCollection    =123        # from enum Obj3dType
	o3d_part                      =104        # from enum Obj3dType
	o3d_partCollection            =108        # from enum Obj3dType
	o3d_placement                 =101        # from enum Obj3dType
	o3d_plane3Points              =16         # from enum Obj3dType
	o3d_planeAngle                =15         # from enum Obj3dType
	o3d_planeEdgePoint            =19         # from enum Obj3dType
	o3d_planeLineToEdge           =22         # from enum Obj3dType
	o3d_planeLineToPlane          =23         # from enum Obj3dType
	o3d_planeMiddle               =66         # from enum Obj3dType
	o3d_planeNormal               =17         # from enum Obj3dType
	o3d_planeOffset               =14         # from enum Obj3dType
	o3d_planeParallel             =20         # from enum Obj3dType
	o3d_planeParam                =137        # from enum Obj3dType
	o3d_planePerpendicular        =21         # from enum Obj3dType
	o3d_planeTangent              =18         # from enum Obj3dType
	o3d_planeXOY                  =1          # from enum Obj3dType
	o3d_planeXOZ                  =2          # from enum Obj3dType
	o3d_planeYOZ                  =3          # from enum Obj3dType
	o3d_point3D                   =70         # from enum Obj3dType
	o3d_pointCS                   =4          # from enum Obj3dType
	o3d_polyline                  =53         # from enum Obj3dType
	o3d_positionLeader3D          =89         # from enum Obj3dType
	o3d_radialDimension3D         =82         # from enum Obj3dType
	o3d_rasterFormat              =112        # from enum Obj3dType
	o3d_ribOperation              =44         # from enum Obj3dType
	o3d_rough3D                   =88         # from enum Obj3dType
	o3d_sTrackingPointsMeasurer   =160        # from enum Obj3dType
	o3d_selectionMng              =145        # from enum Obj3dType
	o3d_sheetMetalBeat            =543        # from enum Obj3dType
	o3d_sheetMetalBend            =75         # from enum Obj3dType
	o3d_sheetMetalBendBended      =537        # from enum Obj3dType
	o3d_sheetMetalBendObject      =540        # from enum Obj3dType
	o3d_sheetMetalBendStraighten  =536        # from enum Obj3dType
	o3d_sheetMetalBendUnfold      =538        # from enum Obj3dType
	o3d_sheetMetalBody            =74         # from enum Obj3dType
	o3d_sheetMetalClosedCorner    =539        # from enum Obj3dType
	o3d_sheetMetalCombinedBend    =535        # from enum Obj3dType
	o3d_sheetMetalConvertFromBody =634        # from enum Obj3dType
	o3d_sheetMetalCowling         =545        # from enum Obj3dType
	o3d_sheetMetalCut             =78         # from enum Obj3dType
	o3d_sheetMetalDimpleCutout    =541        # from enum Obj3dType
	o3d_sheetMetalDrawnCutout     =542        # from enum Obj3dType
	o3d_sheetMetalFlanging        =631        # from enum Obj3dType
	o3d_sheetMetalHole            =77         # from enum Obj3dType
	o3d_sheetMetalLineBend        =76         # from enum Obj3dType
	o3d_sheetMetalLinearCowling   =606        # from enum Obj3dType
	o3d_sheetMetalLouver          =544        # from enum Obj3dType
	o3d_sheetMetalPlate           =534        # from enum Obj3dType
	o3d_sheetMetalPunch           =630        # from enum Obj3dType
	o3d_sheetMetalRib             =614        # from enum Obj3dType
	o3d_sheetMetalUndercut        =533        # from enum Obj3dType
	o3d_shellOperation            =43         # from enum Obj3dType
	o3d_sketch                    =5          # from enum Obj3dType
	o3d_sphereParam               =140        # from enum Obj3dType
	o3d_spline                    =55         # from enum Obj3dType
	o3d_surface                   =127        # from enum Obj3dType
	o3d_surfaceElement            =161        # from enum Obj3dType
	o3d_tessellation              =117        # from enum Obj3dType
	o3d_thread                    =58         # from enum Obj3dType
	o3d_tolerance3D               =92         # from enum Obj3dType
	o3d_torusParam                =141        # from enum Obj3dType
	o3d_unknown                   =0          # from enum Obj3dType
	o3d_userFunc                  =167        # from enum Obj3dType
	o3d_userMateConstraint        =165        # from enum Obj3dType
	o3d_variable                  =100        # from enum Obj3dType
	o3d_variableCollection        =159        # from enum Obj3dType
	o3d_vertex                    =8          # from enum Obj3dType
	o3d_viewProjection            =149        # from enum Obj3dType
	o3d_viewProjectionCollection  =150        # from enum Obj3dType
	pEdit_Part                    =-2         # from enum Part_Type
	pInPlace_Part                 =-4         # from enum Part_Type
	pNew_Part                     =-3         # from enum Part_Type
	pTop_Part                     =-1         # from enum Part_Type
	pnMove                        =0          # from enum Positioner_Type
	pnRotate                      =1          # from enum Positioner_Type
	useColorLayer                 =3          # from enum UseColor
	useColorOur                   =0          # from enum UseColor
	useColorOwner                 =1          # from enum UseColor
	useColorSource                =2          # from enum UseColor
	useColorUnknown               =-1         # from enum UseColor
	vm_HiddenRemoved              =1          # from enum ViewMode
	vm_HiddenThin                 =2          # from enum ViewMode
	vm_Shaded                     =3          # from enum ViewMode
	vm_Wireframe                  =0          # from enum ViewMode
	ksCS3DDashDot                 =4          # from enum ks3DLineStyle
	ksCS3DDashDotLDash2Dots       =5          # from enum ks3DLineStyle
	ksCS3DDashed                  =2          # from enum ks3DLineStyle
	ksCS3DDotted                  =3          # from enum ks3DLineStyle
	ksCS3DNoDrawing               =0          # from enum ks3DLineStyle
	ksCS3DSolid                   =1          # from enum ks3DLineStyle
	ksArc3DByCentre               =1          # from enum ksArc3DBuildingTypeEnum
	ksArc3DByDirrection           =2          # from enum ksArc3DBuildingTypeEnum
	ksArc3DByPoints               =0          # from enum ksArc3DBuildingTypeEnum
	ksArc3DByTanCurve             =3          # from enum ksArc3DBuildingTypeEnum
	ksArc3DAngle1                 =1          # from enum ksArc3DParameterEnum
	ksArc3DAngle2                 =2          # from enum ksArc3DParameterEnum
	ksArc3DCenter                 =0          # from enum ksArc3DParameterEnum
	ksArc3DPoint1                 =1          # from enum ksArc3DParameterEnum
	ksArc3DPoint2                 =2          # from enum ksArc3DParameterEnum
	ksArc3DPoint3                 =3          # from enum ksArc3DParameterEnum
	ksArc3DRadius                 =3          # from enum ksArc3DParameterEnum
	ksArchMeasureByCoefficient    =0          # from enum ksArchMeasureEnum
	ksArchMeasureByLength         =1          # from enum ksArchMeasureEnum
	ksBinormalVector              =2          # from enum ksBasisVectorTypeEnum
	ksNormalVector                =1          # from enum ksBasisVectorTypeEnum
	ksTangentVector               =0          # from enum ksBasisVectorTypeEnum
	ksBendAngleAllBends           =2          # from enum ksBendAngleReleaseTypeEnum
	ksBendAngleBendOnly           =0          # from enum ksBendAngleReleaseTypeEnum
	ksBendAngleIn                 =1          # from enum ksBendAngleReleaseTypeEnum
	ksBendDisposalAllLength       =0          # from enum ksBendDisposalEnum
	ksBendDisposalCentre          =1          # from enum ksBendDisposalEnum
	ksBendDisposalLeft            =2          # from enum ksBendDisposalEnum
	ksBendDisposalLeftAndWidth    =5          # from enum ksBendDisposalEnum
	ksBendDisposalRight           =3          # from enum ksBendDisposalEnum
	ksBendDisposalRightAndWidth   =6          # from enum ksBendDisposalEnum
	ksBendDisposalTwo             =4          # from enum ksBendDisposalEnum
	ksBendLengthByContinue        =0          # from enum ksBendLengthTypeEnum
	ksBendLengthByContour         =1          # from enum ksBendLengthTypeEnum
	ksBendLengthByContourInternal =3          # from enum ksBendLengthTypeEnum
	ksBendLengthByTangentInternal =4          # from enum ksBendLengthTypeEnum
	ksBendLengthByTouch           =2          # from enum ksBendLengthTypeEnum
	ksBendOffsetByCentre          =5          # from enum ksBendOffsetTypeEnum
	ksBendOffsetByTouch           =4          # from enum ksBendOffsetTypeEnum
	ksBendOffsetIn                =0          # from enum ksBendOffsetTypeEnum
	ksBendOffsetLineInside        =3          # from enum ksBendOffsetTypeEnum
	ksBendOffsetLineOutside       =2          # from enum ksBendOffsetTypeEnum
	ksBendOffsetOut               =1          # from enum ksBendOffsetTypeEnum
	ksBendReleaseByCircle         =1          # from enum ksBendReleaseTypeEnum
	ksBendReleaseByRect           =0          # from enum ksBendReleaseTypeEnum
	ksBendSideByAngle             =0          # from enum ksBendSideTypeEnum
	ksBendSideByWidening          =1          # from enum ksBendSideTypeEnum
	ksBendByCentre                =4          # from enum ksBendTypeEnum
	ksBendByTouch                 =3          # from enum ksBendTypeEnum
	ksBendLineInside              =2          # from enum ksBendTypeEnum
	ksBendLineOutside             =1          # from enum ksBendTypeEnum
	ksLineBend                    =0          # from enum ksBendTypeEnum
	ksChamferSideAngle            =0          # from enum ksChamferBuildingTypeEnum
	ksChamferTwoSides             =1          # from enum ksChamferBuildingTypeEnum
	ksAllBodies                   =3          # from enum ksChooseBodiesType
	ksAutomaticDefinition         =1          # from enum ksChooseBodiesType
	ksManualEditing               =2          # from enum ksChooseBodiesType
	ksNewBody                     =0          # from enum ksChooseBodiesType
	ksChAllParts                  =3          # from enum ksChoosePartsType
	ksChAutomaticDefinition       =1          # from enum ksChoosePartsType
	ksChManualEditing             =2          # from enum ksChoosePartsType
	ksChNoLibraryParts            =4          # from enum ksChoosePartsType
	ksChBodies                    =3          # from enum ksChooseType
	ksChBodiesAndParts            =1          # from enum ksChooseType
	ksChParts                     =2          # from enum ksChooseType
	ksCPChessOrderByAxis1         =1          # from enum ksCircularPatternBuildingTypeEnum
	ksCPChessOrderByAxis2         =2          # from enum ksCircularPatternBuildingTypeEnum
	ksCPSaveAll                   =0          # from enum ksCircularPatternBuildingTypeEnum
	ksClosingCJoint               =0          # from enum ksClosingClosedTypeEnum
	ksClosingCOver                =1          # from enum ksClosingClosedTypeEnum
	ksClosingCTightClosure        =2          # from enum ksClosingClosedTypeEnum
	ksCorneringCircled            =3          # from enum ksClosingCorneringEnum
	ksCorneringJointOnBorder      =1          # from enum ksClosingCorneringEnum
	ksCorneringJointOnChord       =2          # from enum ksClosingCorneringEnum
	ksCorneringNone               =0          # from enum ksClosingCorneringEnum
	ksCorneringHPAngle            =1          # from enum ksClosingHolePlacementEnum
	ksCorneringHPBend             =0          # from enum ksClosingHolePlacementEnum
	ksCorneringHPPoint            =2          # from enum ksClosingHolePlacementEnum
	ksClosingAngles               =0          # from enum ksClosingTypeEnum
	ksClosingBegin                =1          # from enum ksClosingTypeEnum
	ksClosingEnd                  =2          # from enum ksClosingTypeEnum
	ksCLByPoints                  =0          # from enum ksCloudPointsSurfaceBuildingTypeEnum
	ksCLByPole                    =1          # from enum ksCloudPointsSurfaceBuildingTypeEnum
	ksCLPolyhedral                =2          # from enum ksCloudPointsSurfaceBuildingTypeEnum
	ksCLAuto                      =0          # from enum ksCloudTypeEnum
	ksCLLocalCS                   =1          # from enum ksCloudTypeEnum
	ksCLScreen                    =2          # from enum ksCloudTypeEnum
	ksCNAngle                     =1          # from enum ksConicTypeEnum
	ksCNDiameter                  =0          # from enum ksConicTypeEnum
	ksCPByObject                  =0          # from enum ksConjunctivePointTypeEnum
	ksCPManualDirection           =1          # from enum ksConjunctivePointTypeEnum
	ksCTNormal                    =2          # from enum ksConnectTypeEnum
	ksCTPosition                  =0          # from enum ksConnectTypeEnum
	ksCTSmooth                    =3          # from enum ksConnectTypeEnum
	ksCTTangent                   =1          # from enum ksConnectTypeEnum
	ksCTUnknown                   =-1         # from enum ksConnectTypeEnum
	ksCBTEdges                    =1          # from enum ksContour3DBuildingTypeTypeEnum
	ksCBTEquidistant              =2          # from enum ksContour3DBuildingTypeTypeEnum
	ksCBTUnknown                  =0          # from enum ksContour3DBuildingTypeTypeEnum
	ksCTAuto                      =0          # from enum ksContour3DTypeEnum
	ksCTSketch                    =3          # from enum ksContour3DTypeEnum
	ksCTSpace                     =1          # from enum ksContour3DTypeEnum
	ksCTSurface                   =2          # from enum ksContour3DTypeEnum
	ksCLawX                       =0          # from enum ksCoordLawEnum
	ksCLawY                       =1          # from enum ksCoordLawEnum
	ksCLawZ                       =2          # from enum ksCoordLawEnum
	ksCGBTBodyFaceGrouping        =1          # from enum ksCopyGeometryBuildingTypeEnum
	ksCGBTWithoutGrouping         =0          # from enum ksCopyGeometryBuildingTypeEnum
	ksCTDepthAngle                =1          # from enum ksCountersinkTypeEnum
	ksCTDiameterAngle             =0          # from enum ksCountersinkTypeEnum
	ksCTDiameterDepth             =2          # from enum ksCountersinkTypeEnum
	ksCrossSectionPlaneByModelPlane=0          # from enum ksCrossSectionPlaneBuildingTypeEnum
	ksCrossSectionPlaneByOtherStep=1          # from enum ksCrossSectionPlaneBuildingTypeEnum
	ksCPNearest                   =0          # from enum ksCurveProjectionTypeEnum
	ksCPNearestByDirection        =1          # from enum ksCurveProjectionTypeEnum
	ksCutByContour                =0          # from enum ksCutBuildingTypeEnum
	ksCutByPlane                  =1          # from enum ksCutBuildingTypeEnum
	ksD3CAssociated               =26         # from enum ksD3ConverterOptionsEnum
	ksD3CBRep                     =20         # from enum ksD3ConverterOptionsEnum
	ksD3COAttributes              =18         # from enum ksD3ConverterOptionsEnum
	ksD3COBodyes                  =0          # from enum ksD3ConverterOptionsEnum
	ksD3COCurves                  =4          # from enum ksD3ConverterOptionsEnum
	ksD3CODimensions              =16         # from enum ksD3ConverterOptionsEnum
	ksD3CODocumentProperties      =12         # from enum ksD3ConverterOptionsEnum
	ksD3COInvisibleObjects        =8          # from enum ksD3ConverterOptionsEnum
	ksD3COPoints                  =10         # from enum ksD3ConverterOptionsEnum
	ksD3COSketches                =6          # from enum ksD3ConverterOptionsEnum
	ksD3COStyle                   =28         # from enum ksD3ConverterOptionsEnum
	ksD3COSurfaces                =2          # from enum ksD3ConverterOptionsEnum
	ksD3COTechnicalDemand         =14         # from enum ksD3ConverterOptionsEnum
	ksD3CPolygonal                =22         # from enum ksD3ConverterOptionsEnum
	ksD3CPolygonalLOD0            =24         # from enum ksD3ConverterOptionsEnum
	ksDTObject                    =2          # from enum ksDepthTypeEnum
	ksDTReachThrough              =1          # from enum ksDepthTypeEnum
	ksDTValue                     =0          # from enum ksDepthTypeEnum
	ksDCSTByBorderPoints          =4          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByFreePlane             =0          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByOffsetPlane           =1          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByRotatedPlane          =2          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTByZone                  =3          # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksDCSTUnknown                 =-1         # from enum ksDynamicCrossSectionStepBuildingTypeEnum
	ksECChooseObject1             =1          # from enum ksEditColorTypeEnum
	ksECChooseObject2             =2          # from enum ksEditColorTypeEnum
	ksECChooseObject3             =3          # from enum ksEditColorTypeEnum
	ksECDimensions                =7          # from enum ksEditColorTypeEnum
	ksECFacePhantom               =5          # from enum ksEditColorTypeEnum
	ksECLabelsPhantom             =6          # from enum ksEditColorTypeEnum
	ksECPassiveParts              =4          # from enum ksEditColorTypeEnum
	ksECSelectObject              =0          # from enum ksEditColorTypeEnum
	ksESByLayer                   =2          # from enum ksEditableStateEnum
	ksESDisable                   =0          # from enum ksEditableStateEnum
	ksESEnable                    =1          # from enum ksEditableStateEnum
	ksESUndefined                 =-1         # from enum ksEditableStateEnum
	ksEFConic                     =1          # from enum ksEndFaceTypeEnum
	ksEFFlat                      =0          # from enum ksEndFaceTypeEnum
	ksEFSphere                    =2          # from enum ksEndFaceTypeEnum
	ksECMCircle                   =2          # from enum ksEquidistant3DCutModeEnum
	ksECMLineSeg                  =1          # from enum ksEquidistant3DCutModeEnum
	ksECMUnknown                  =0          # from enum ksEquidistant3DCutModeEnum
	ksEvShiftKeepAngle            =1          # from enum ksEvolutionShiftSketchTypeEnum
	ksEvShiftOrtogonal            =2          # from enum ksEvolutionShiftSketchTypeEnum
	ksEvShiftParallel             =0          # from enum ksEvolutionShiftSketchTypeEnum
	ksETLUnknown                  =-1         # from enum ksExtensionLimitTypeEnum
	ksETLVertex                   =1          # from enum ksExtensionLimitTypeEnum
	ksETLength                    =0          # from enum ksExtensionLimitTypeEnum
	ksESTDirection                =2          # from enum ksExtensionSurfaceTypeEnum
	ksESTSelf                     =0          # from enum ksExtensionSurfaceTypeEnum
	ksESTTangent                  =1          # from enum ksExtensionSurfaceTypeEnum
	ksESTUnknown                  =-1         # from enum ksExtensionSurfaceTypeEnum
	ksFSMAll                      =3          # from enum ksFacetCullingMode
	ksFSMBack                     =2          # from enum ksFacetCullingMode
	ksFSMFront                    =1          # from enum ksFacetCullingMode
	ksFSMNone                     =0          # from enum ksFacetCullingMode
	ksFSBrokenLink                =2097152    # from enum ksFeatureStateEnum
	ksFSComprisedOfParts          =16         # from enum ksFeatureStateEnum
	ksFSCurrent                   =32         # from enum ksFeatureStateEnum
	ksFSDetailedFold              =128        # from enum ksFeatureStateEnum
	ksFSEditImpossible            =4096       # from enum ksFeatureStateEnum
	ksFSEditRestricted            =2048       # from enum ksFeatureStateEnum
	ksFSFixedComponent            =8192       # from enum ksFeatureStateEnum
	ksFSInside3dMacro             =4          # from enum ksFeatureStateEnum
	ksFSLCSDependent              =8          # from enum ksFeatureStateEnum
	ksFSLocked                    =1          # from enum ksFeatureStateEnum
	ksFSNone                      =0          # from enum ksFeatureStateEnum
	ksFSPutInRecalcState          =16384      # from enum ksFeatureStateEnum
	ksFSReadOnlyAccessA3d         =32768      # from enum ksFeatureStateEnum
	ksFSReadOnlyAccessM3d         =64         # from enum ksFeatureStateEnum
	ksFSRebuild                   =2          # from enum ksFeatureStateEnum
	ksFSSketchDefined             =512        # from enum ksFeatureStateEnum
	ksFSSketchRedefined           =1024       # from enum ksFeatureStateEnum
	ksFSSketchUndefined           =256        # from enum ksFeatureStateEnum
	ksFSUncuttable                =65536      # from enum ksFeatureStateEnum
	ksFSUpdateNeeded              =1048576    # from enum ksFeatureStateEnum
	ksFilletCircleArc             =0          # from enum ksFilletBuildingTypeEnum
	ksFilletCoefficient           =2          # from enum ksFilletBuildingTypeEnum
	ksFilletEllipseArc            =1          # from enum ksFilletBuildingTypeEnum
	ksFilletHord                  =3          # from enum ksFilletBuildingTypeEnum
	ksFilletOffsetByAngle         =2          # from enum ksFilletOffsetModeEnum
	ksFilletOffsetByLength        =1          # from enum ksFilletOffsetModeEnum
	ksFilletOffsetByPersent       =0          # from enum ksFilletOffsetModeEnum
	ksGabaritByBorderPoints       =0          # from enum ksGabaritBuildingTypeEnum
	ksGabaritByCenterAndBorder    =1          # from enum ksGabaritBuildingTypeEnum
	ksHoleCutByDepth              =1          # from enum ksHoleCutTypeEnum
	ksHoleCutByWidth              =0          # from enum ksHoleCutTypeEnum
	ksHoleCutUpToSurface          =2          # from enum ksHoleCutTypeEnum
	ksHTBase                      =0          # from enum ksHoleTypeEnum
	ksHTConic                     =4          # from enum ksHoleTypeEnum
	ksHTCounterbore               =1          # from enum ksHoleTypeEnum
	ksHTCounterdrill              =3          # from enum ksHoleTypeEnum
	ksHTCountersinking            =2          # from enum ksHoleTypeEnum
	ksHTLfrLibrary                =5          # from enum ksHoleTypeEnum
	ksJalousieExtract             =0          # from enum ksJalousieBuildingTypeEnum
	ksJalousieTrim                =1          # from enum ksJalousieBuildingTypeEnum
	ksJalousieNormal              =1          # from enum ksJalousieFormEndEnum
	ksJalousieTangent             =0          # from enum ksJalousieFormEndEnum
	ksJalousieAllHeight           =0          # from enum ksJalousieHeightTypeEnum
	ksJalousieSlotHeight          =2          # from enum ksJalousieHeightTypeEnum
	ksJalousieUpToFaceHeight      =1          # from enum ksJalousieHeightTypeEnum
	ksTLawByExpression            =3          # from enum ksLawTypeEnum
	ksTLawConst                   =0          # from enum ksLawTypeEnum
	ksTLawCube                    =2          # from enum ksLawTypeEnum
	ksTLawLinear                  =1          # from enum ksLawTypeEnum
	ksLBDistance                  =0          # from enum ksLengthBuildingTypeEnum
	ksLBToSurface                 =3          # from enum ksLengthBuildingTypeEnum
	ksLBToVertex                  =2          # from enum ksLengthBuildingTypeEnum
	ksLBTByPoint                  =0          # from enum ksLineBuildingType
	ksLBTByPoint3DParams          =6          # from enum ksLineBuildingType
	ksLBTParallel                 =4          # from enum ksLineBuildingType
	ksLBTPerpendicular            =5          # from enum ksLineBuildingType
	ksLBTXDirection               =1          # from enum ksLineBuildingType
	ksLBTYDirection               =2          # from enum ksLineBuildingType
	ksLBTZDirection               =3          # from enum ksLineBuildingType
	ksLSTPointLenghtAngle         =1          # from enum ksLineSegment3DTypeEnum
	ksLSTTwoPoints                =0          # from enum ksLineSegment3DTypeEnum
	ksLPChessOrderByAxis1         =3          # from enum ksLinearPatternBuildingTypeEnum
	ksLPChessOrderByAxis2         =4          # from enum ksLinearPatternBuildingTypeEnum
	ksLPSaveAll                   =0          # from enum ksLinearPatternBuildingTypeEnum
	ksLPSaveAlongAxially          =2          # from enum ksLinearPatternBuildingTypeEnum
	ksLPSaveAlongPerimeter        =1          # from enum ksLinearPatternBuildingTypeEnum
	ksLCompletely                 =0          # from enum ksLoadStateEnum
	ksLGabarit                    =4          # from enum ksLoadStateEnum
	ksLPartially                  =3          # from enum ksLoadStateEnum
	ksLTriangles                  =2          # from enum ksLoadStateEnum
	ksLUnknown                    =-1         # from enum ksLoadStateEnum
	ksLUnload                     =1          # from enum ksLoadStateEnum
	ksLoftAuto                    =0          # from enum ksLoftBuildingType
	ksLoftByNormal                =1          # from enum ksLoftBuildingType
	ksLoftByObject                =2          # from enum ksLoftBuildingType
	ksLoftCupola                  =3          # from enum ksLoftBuildingType
	ksManipulatorModeDefault      =1          # from enum ksManipulatorModeEnum
	ksManipulatorModeNotHandleEditor=2          # from enum ksManipulatorModeEnum
	ksMPAxisX                     =1          # from enum ksManipulatorPrimitiveEnum
	ksMPAxisY                     =2          # from enum ksManipulatorPrimitiveEnum
	ksMPAxisZ                     =3          # from enum ksManipulatorPrimitiveEnum
	ksMPConturXY                  =7          # from enum ksManipulatorPrimitiveEnum
	ksMPConturXZ                  =8          # from enum ksManipulatorPrimitiveEnum
	ksMPConturYZ                  =9          # from enum ksManipulatorPrimitiveEnum
	ksMPNone                      =0          # from enum ksManipulatorPrimitiveEnum
	ksMPOriginal                  =13         # from enum ksManipulatorPrimitiveEnum
	ksMPPlaceXOY                  =4          # from enum ksManipulatorPrimitiveEnum
	ksMPPlaceXOZ                  =5          # from enum ksManipulatorPrimitiveEnum
	ksMPPlaceYOZ                  =6          # from enum ksManipulatorPrimitiveEnum
	ksMPTextX                     =10         # from enum ksManipulatorPrimitiveEnum
	ksMPTextY                     =11         # from enum ksManipulatorPrimitiveEnum
	ksMPTextZ                     =12         # from enum ksManipulatorPrimitiveEnum
	ksEditDoubleManipulator       =2          # from enum ksManipulatorTypeEnum
	ksPlacement3DManipulator      =1          # from enum ksManipulatorTypeEnum
	ksMCAlignmentClosest          =0          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignmentCooriented       =1          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignmentOpposite         =-1         # from enum ksMateConstraintAlignmentEnum
	ksMCAlignmentUnknown          =2          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignment_1               =3          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignment_2               =4          # from enum ksMateConstraintAlignmentEnum
	ksMCAlignment_3               =5          # from enum ksMateConstraintAlignmentEnum
	ksMCReverse_1                 =6          # from enum ksMateConstraintAlignmentEnum
	ksMCReverse_2                 =7          # from enum ksMateConstraintAlignmentEnum
	ksMCReverse_3                 =8          # from enum ksMateConstraintAlignmentEnum
	ksMFixedPart1                 =1          # from enum ksMateFixedTypeEnum
	ksMFixedPart2                 =2          # from enum ksMateFixedTypeEnum
	ksMFixedUnknown               =0          # from enum ksMateFixedTypeEnum
	ksMMotionLinear               =1          # from enum ksMateMotionTypeEnum
	ksMMotionRotation             =2          # from enum ksMateMotionTypeEnum
	ksMMotionUnknown              =0          # from enum ksMateMotionTypeEnum
	ksMTangentByCircle            =3          # from enum ksMateTangentTypeEnum
	ksMTangentByGeneratrixLine    =2          # from enum ksMateTangentTypeEnum
	ksMTangentByPoint             =1          # from enum ksMateTangentTypeEnum
	ksMTangentUnknown             =0          # from enum ksMateTangentTypeEnum
	ksMateCircle                  =8          # from enum ksMateType
	ksMateCone                    =5          # from enum ksMateType
	ksMateCylinder                =4          # from enum ksMateType
	ksMateLine                    =2          # from enum ksMateType
	ksMatePlane                   =3          # from enum ksMateType
	ksMatePoint                   =1          # from enum ksMateType
	ksMateSphere                  =6          # from enum ksMateType
	ksMateTorus                   =7          # from enum ksMateType
	ksMateUnknown                 =0          # from enum ksMateType
	ks3DCurve                     =0          # from enum ksMathCurve3DTypeEnum
	ksArc3D                       =3          # from enum ksMathCurve3DTypeEnum
	ksBSpline                     =25         # from enum ksMathCurve3DTypeEnum
	ksBezier3D                    =11         # from enum ksMathCurve3DTypeEnum
	ksBridgeCurve3D               =18         # from enum ksMathCurve3DTypeEnum
	ksCharacterCurve3D            =19         # from enum ksMathCurve3DTypeEnum
	ksConeSpiral                  =5          # from enum ksMathCurve3DTypeEnum
	ksContour3D                   =26         # from enum ksMathCurve3DTypeEnum
	ksContourOnPlane              =21         # from enum ksMathCurve3DTypeEnum
	ksContourOnSurface            =20         # from enum ksMathCurve3DTypeEnum
	ksCrookedSpiral               =7          # from enum ksMathCurve3DTypeEnum
	ksCubicSpline3D               =13         # from enum ksMathCurve3DTypeEnum
	ksCurveSpiral                 =6          # from enum ksMathCurve3DTypeEnum
	ksHermit3D                    =12         # from enum ksMathCurve3DTypeEnum
	ksLine3D                      =1          # from enum ksMathCurve3DTypeEnum
	ksLineSegment3D               =2          # from enum ksMathCurve3DTypeEnum
	ksNurbs3D                     =10         # from enum ksMathCurve3DTypeEnum
	ksOffsetCurve3D               =15         # from enum ksMathCurve3DTypeEnum
	ksPlaneCurve                  =14         # from enum ksMathCurve3DTypeEnum
	ksPolyCurve3D                 =8          # from enum ksMathCurve3DTypeEnum
	ksPolyline3D                  =9          # from enum ksMathCurve3DTypeEnum
	ksReparamCurve3D              =17         # from enum ksMathCurve3DTypeEnum
	ksSilhouetteCurve             =23         # from enum ksMathCurve3DTypeEnum
	ksSpiral                      =4          # from enum ksMathCurve3DTypeEnum
	ksSurfaceCurve                =22         # from enum ksMathCurve3DTypeEnum
	ksSurfaceIntersectionCurve    =24         # from enum ksMathCurve3DTypeEnum
	ksTrimmedCurve3D              =16         # from enum ksMathCurve3DTypeEnum
	ks3DSurface                   =0          # from enum ksMathSurface3DTypeEnum
	ksBendedUnbendedSurface       =37         # from enum ksMathSurface3DTypeEnum
	ksChamferSurface              =32         # from enum ksMathSurface3DTypeEnum
	ksChannelSurface              =34         # from enum ksMathSurface3DTypeEnum
	ksConeSurface                 =3          # from enum ksMathSurface3DTypeEnum
	ksConicBendedSurface          =40         # from enum ksMathSurface3DTypeEnum
	ksConicUnbendedSurface        =41         # from enum ksMathSurface3DTypeEnum
	ksCoonsPatchSurface           =28         # from enum ksMathSurface3DTypeEnum
	ksCornerSurface               =26         # from enum ksMathSurface3DTypeEnum
	ksCoverSurface                =27         # from enum ksMathSurface3DTypeEnum
	ksCurveBoundedSurface         =36         # from enum ksMathSurface3DTypeEnum
	ksCylinderSurface             =4          # from enum ksMathSurface3DTypeEnum
	ksCylindricBendedSurface      =38         # from enum ksMathSurface3DTypeEnum
	ksCylindricUnbendedSurface    =39         # from enum ksMathSurface3DTypeEnum
	ksDeformedSurface             =24         # from enum ksMathSurface3DTypeEnum
	ksElementarySurface           =1          # from enum ksMathSurface3DTypeEnum
	ksElevationSurface            =13         # from enum ksMathSurface3DTypeEnum
	ksEvolutionSurface            =10         # from enum ksMathSurface3DTypeEnum
	ksExactionSurface             =11         # from enum ksMathSurface3DTypeEnum
	ksExpansionSurface            =12         # from enum ksMathSurface3DTypeEnum
	ksExplorationSurface          =42         # from enum ksMathSurface3DTypeEnum
	ksExtrusionSurface            =8          # from enum ksMathSurface3DTypeEnum
	ksFilletSurface               =33         # from enum ksMathSurface3DTypeEnum
	ksFreeSurface                 =200        # from enum ksMathSurface3DTypeEnum
	ksGridSurface                 =20         # from enum ksMathSurface3DTypeEnum
	ksHermitSurface               =18         # from enum ksMathSurface3DTypeEnum
	ksJoinSurface                 =35         # from enum ksMathSurface3DTypeEnum
	ksLoftedSurface               =30         # from enum ksMathSurface3DTypeEnum
	ksMeshSurface                 =29         # from enum ksMathSurface3DTypeEnum
	ksNurbsSurface                =25         # from enum ksMathSurface3DTypeEnum
	ksOffsetSurface               =23         # from enum ksMathSurface3DTypeEnum
	ksPlane                       =2          # from enum ksMathSurface3DTypeEnum
	ksPolySurface                 =17         # from enum ksMathSurface3DTypeEnum
	ksRevolutionSurface           =9          # from enum ksMathSurface3DTypeEnum
	ksRuledSurface                =15         # from enum ksMathSurface3DTypeEnum
	ksSectorSurface               =16         # from enum ksMathSurface3DTypeEnum
	ksSmoothSurface               =31         # from enum ksMathSurface3DTypeEnum
	ksSphereSurface               =5          # from enum ksMathSurface3DTypeEnum
	ksSpiralSurface               =14         # from enum ksMathSurface3DTypeEnum
	ksSplineSurface               =19         # from enum ksMathSurface3DTypeEnum
	ksSweptSurface                =7          # from enum ksMathSurface3DTypeEnum
	ksTorusSurface                =6          # from enum ksMathSurface3DTypeEnum
	ksTriBezierSurface            =21         # from enum ksMathSurface3DTypeEnum
	ksTriSplineSurface            =22         # from enum ksMathSurface3DTypeEnum
	ksMResAxisAxisCoaxial         =1          # from enum ksMeasureResultEnum
	ksMResAxisAxisDistant         =4          # from enum ksMeasureResultEnum
	ksMResAxisAxisIntersect       =3          # from enum ksMeasureResultEnum
	ksMResAxisAxisParallel        =2          # from enum ksMeasureResultEnum
	ksMResAxisSurfColinear        =5          # from enum ksMeasureResultEnum
	ksMResAxisSurfDistant         =8          # from enum ksMeasureResultEnum
	ksMResAxisSurfIntersect       =7          # from enum ksMeasureResultEnum
	ksMResAxisSurfParallel        =6          # from enum ksMeasureResultEnum
	ksMResSurfSurfColinear        =9          # from enum ksMeasureResultEnum
	ksMResSurfSurfIntersecting    =11         # from enum ksMeasureResultEnum
	ksMResSurfSurfParallel        =10         # from enum ksMeasureResultEnum
	ksMResUnknown                 =0          # from enum ksMeasureResultEnum
	ksMACircular                  =2          # from enum ksMeshAroundPointTypeEnum
	ksMAHexagonal                 =3          # from enum ksMeshAroundPointTypeEnum
	ksMALinear                    =0          # from enum ksMeshAroundPointTypeEnum
	ksMAUVLinear                  =1          # from enum ksMeshAroundPointTypeEnum
	ksMPByPoints                  =0          # from enum ksMeshPointsSurfaceBuildingTypeEnum
	ksMPByPole                    =1          # from enum ksMeshPointsSurfaceBuildingTypeEnum
	ksModelDrawingElementAll      =65535      # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementAuxObjs  =256        # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementBackground=1          # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementCompBodies=16         # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementCompObjs =32         # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementEditor   =4096       # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementMeshCutter=16384      # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementNone     =0          # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementNotifyLibs=512        # from enum ksModelDrawingElementsEnum
	ksModelDrawingElementWidgets  =8192       # from enum ksModelDrawingElementsEnum
	ksMOAllParam                  =1          # from enum ksModelObjectParamTypeEnum
	ksMOCurrentLSKAllParam        =3          # from enum ksModelObjectParamTypeEnum
	ksMOPartAllParam              =2          # from enum ksModelObjectParamTypeEnum
	ksArbitraryThicknesses        =0          # from enum ksMultiThicknessGroupTypeEnum
	ksSetsThicknesses             =1          # from enum ksMultiThicknessGroupTypeEnum
	ksFilterAll                   =0          # from enum ksObjectsFilter3DEnum
	ksFilterBodies                =7          # from enum ksObjectsFilter3DEnum
	ksFilterCAxis                 =5          # from enum ksObjectsFilter3DEnum
	ksFilterCPlanes               =4          # from enum ksObjectsFilter3DEnum
	ksFilterCS                    =11         # from enum ksObjectsFilter3DEnum
	ksFilterControlPoints         =12         # from enum ksObjectsFilter3DEnum
	ksFilterCurves                =10         # from enum ksObjectsFilter3DEnum
	ksFilterDesignations          =14         # from enum ksObjectsFilter3DEnum
	ksFilterEdges                 =2          # from enum ksObjectsFilter3DEnum
	ksFilterFaces                 =1          # from enum ksObjectsFilter3DEnum
	ksFilterParts                 =6          # from enum ksObjectsFilter3DEnum
	ksFilterPoints3D              =13         # from enum ksObjectsFilter3DEnum
	ksFilterSketches              =9          # from enum ksObjectsFilter3DEnum
	ksFilterSurfaces              =8          # from enum ksObjectsFilter3DEnum
	ksFilterThread                =15         # from enum ksObjectsFilter3DEnum
	ksFilterVertexs               =3          # from enum ksObjectsFilter3DEnum
	ksOGDraftPosition             =2          # from enum ksOffsetGapType
	ksOGLength                    =1          # from enum ksOffsetGapType
	ksOGParametrU                 =0          # from enum ksOffsetGapType
	ksOperationCut                =2          # from enum ksOperationResultEnum
	ksOperationIntersect          =3          # from enum ksOperationResultEnum
	ksOperationNewBody            =1          # from enum ksOperationResultEnum
	ksOperationUnion              =0          # from enum ksOperationResultEnum
	ksAxisOrientation             =0          # from enum ksOrientationTypeEnum
	ksEulerCorners                =1          # from enum ksOrientationTypeEnum
	ksOrientByObject              =2          # from enum ksOrientationTypeEnum
	ksAllParts                    =0          # from enum ksPart7CollectionTypeEnum
	ksUniqueParts                 =1          # from enum ksPart7CollectionTypeEnum
	ksATDisable                   =2          # from enum ksPartAccessTypeEnum
	ksATEditable                  =0          # from enum ksPartAccessTypeEnum
	ksATReadOnly                  =1          # from enum ksPartAccessTypeEnum
	ksATUncertainty               =-1         # from enum ksPartAccessTypeEnum
	ksCRAuto                      =0          # from enum ksPatternBasePointTypeEnum
	ksCRFirstObject               =2          # from enum ksPatternBasePointTypeEnum
	ksCRManual                    =1          # from enum ksPatternBasePointTypeEnum
	ksOrientationByNormal         =1          # from enum ksPatternExemplarsOrientationTypeEnum
	ksOrientationByObject         =2          # from enum ksPatternExemplarsOrientationTypeEnum
	ksOrientationSave             =0          # from enum ksPatternExemplarsOrientationTypeEnum
	ksOffsetByAngle               =3          # from enum ksPoint3DCurveParamTypeEnum
	ksOffsetByLen                 =2          # from enum ksPoint3DCurveParamTypeEnum
	ksOffsetByU                   =1          # from enum ksPoint3DCurveParamTypeEnum
	ksOffsetByCoords              =3          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetByCylinderCoords      =4          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetByLenFromObj          =2          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetBySphereCoords        =5          # from enum ksPoint3DSurfaceParamTypeEnum
	ksOffsetByUV                  =1          # from enum ksPoint3DSurfaceParamTypeEnum
	ksPCenter                     =4          # from enum ksPoint3DTypeEnum
	ksPCurve                      =5          # from enum ksPoint3DTypeEnum
	ksPCylindrCoord               =8          # from enum ksPoint3DTypeEnum
	ksPDisplace                   =2          # from enum ksPoint3DTypeEnum
	ksPIntersect                  =3          # from enum ksPoint3DTypeEnum
	ksPParamCoord                 =1          # from enum ksPoint3DTypeEnum
	ksPProjection                 =7          # from enum ksPoint3DTypeEnum
	ksPSphericCoord               =9          # from enum ksPoint3DTypeEnum
	ksPSurface                    =6          # from enum ksPoint3DTypeEnum
	ksPUnknown                    =0          # from enum ksPoint3DTypeEnum
	ksPAOCByParametricStep        =2          # from enum ksPointsArrOnCurveTypeEnum
	ksPAOCByPointsCount           =0          # from enum ksPointsArrOnCurveTypeEnum
	ksPAOCByStep                  =1          # from enum ksPointsArrOnCurveTypeEnum
	ksPAOSByAngularDeflection     =1          # from enum ksPointsArrOnSurfaceTypeEnum
	ksPAOSByLinearDeflection      =0          # from enum ksPointsArrOnSurfaceTypeEnum
	ksPAOSByMeshAroundPoint       =2          # from enum ksPointsArrOnSurfaceTypeEnum
	ksPAOSByPointsUVCount         =-1         # from enum ksPointsArrOnSurfaceTypeEnum
	ksPressFormingAllHeight       =0          # from enum ksPressFormingHeightTypeEnum
	ksPressFormingInHeight        =2          # from enum ksPressFormingHeightTypeEnum
	ksPressFormingOutHeight       =1          # from enum ksPressFormingHeightTypeEnum
	ksProcessFilterBodies         =0          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterExcludeExternalObjects=1000       # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterObjects        =2          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterOperations     =3          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterParts          =4          # from enum ksProcessObjectsFilter3DEnum
	ksProcessFilterSurfaces       =1          # from enum ksProcessObjectsFilter3DEnum
	ksPOByLayer                   =2          # from enum ksProjectionOptionEnum
	ksPODisable                   =0          # from enum ksProjectionOptionEnum
	ksPOEnable                    =1          # from enum ksProjectionOptionEnum
	ksPOUndefined                 =-1         # from enum ksProjectionOptionEnum
	ksRTIndifferent               =1          # from enum ksRelationTypeEnum
	ksRTStrong                    =2          # from enum ksRelationTypeEnum
	ksRTUnknown                   =0          # from enum ksRelationTypeEnum
	ksRibSideDown                 =3          # from enum ksRibSideEnum
	ksRibSideLeft                 =0          # from enum ksRibSideEnum
	ksRibSideRight                =1          # from enum ksRibSideEnum
	ksRibSideUp                   =2          # from enum ksRibSideEnum
	ksRTAngle                     =0          # from enum ksRotatedTypeEnum
	ksRTSurface                   =2          # from enum ksRotatedTypeEnum
	ksRTVertex                    =1          # from enum ksRotatedTypeEnum
	ksRuledBodder1                =0          # from enum ksRuledBorderEnum
	ksRuledBodder2                =1          # from enum ksRuledBorderEnum
	ksRuledJoint1                 =0          # from enum ksRuledJointEnum
	ksRuledJoint2                 =1          # from enum ksRuledJointEnum
	ksSHRibBuildingDepthAngle     =2          # from enum ksSHRibBuildingTypeEnum
	ksSHRibBuildingHeightAngle    =0          # from enum ksSHRibBuildingTypeEnum
	ksSHRibBuildingTwoHeights     =1          # from enum ksSHRibBuildingTypeEnum
	ksSHRibCuttingU               =1          # from enum ksSHRibCutingTypeEnum
	ksSHRibCuttingV               =0          # from enum ksSHRibCutingTypeEnum
	ksSmAngle                     =2          # from enum ksSegmentationMethodEnum
	ksSmHeight                    =3          # from enum ksSegmentationMethodEnum
	ksSmLength                    =1          # from enum ksSegmentationMethodEnum
	ksSmQuantity                  =0          # from enum ksSegmentationMethodEnum
	ksSelectionNoBand             =0          # from enum ksSelectionBandMode
	ksSelectionWhenNoNearestObject=2          # from enum ksSelectionBandMode
	ksSheetMetalMatrix            =1          # from enum ksSheetMetalPunchBuildingTypeEnum
	ksSheetMetalPunch             =0          # from enum ksSheetMetalPunchBuildingTypeEnum
	ksSheetMetalPunchHeightByBody =0          # from enum ksSheetMetalPunchThicknessTypeEnum
	ksSheetMetalPunchHeightByValue=1          # from enum ksSheetMetalPunchThicknessTypeEnum
	ksShoulderAngle               =4          # from enum ksShoulderBuildingTypeEnum
	ksShoulderAngleOff            =-4         # from enum ksShoulderBuildingTypeEnum
	ksShoulderCircleByHeightRadius2=18         # from enum ksShoulderBuildingTypeEnum
	ksShoulderCircleByHeightWidth1=3          # from enum ksShoulderBuildingTypeEnum
	ksShoulderCircleByRadiusWidth1=17         # from enum ksShoulderBuildingTypeEnum
	ksShoulderHeight              =2          # from enum ksShoulderBuildingTypeEnum
	ksShoulderHeightOff           =-2         # from enum ksShoulderBuildingTypeEnum
	ksShoulderRadius2             =16         # from enum ksShoulderBuildingTypeEnum
	ksShoulderRadius2Off          =-16        # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByAngleWidth1Width2=13         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByAngleWidth1Width2Radius2=29         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidth1 =7          # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidth2 =14         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidth2Radius2=30         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighAngleWidthRadius2=23         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighWidth1Width2=11         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUByHeighWidth1Width2Radius2=27         # from enum ksShoulderBuildingTypeEnum
	ksShoulderUnknown             =0          # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByHeighAngleRadius2=22         # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByHeighAngleWidth1 =7          # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByHeighRadius2Width1=19         # from enum ksShoulderBuildingTypeEnum
	ksShoulderVByRadius2AngleWidth1=21         # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth1              =1          # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth1Off           =-1         # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth2              =8          # from enum ksShoulderBuildingTypeEnum
	ksShoulderWidth2Off           =-8         # from enum ksShoulderBuildingTypeEnum
	ksShoulderCutingCircle        =0          # from enum ksShoulderCutingTypeEnum
	ksShoulderCutingU             =1          # from enum ksShoulderCutingTypeEnum
	ksShoulderCutingV             =2          # from enum ksShoulderCutingTypeEnum
	ksShoulderChopped             =2          # from enum ksShoulderTypeEnum
	ksShoulderClosed              =0          # from enum ksShoulderTypeEnum
	ksShoulderOpened              =1          # from enum ksShoulderTypeEnum
	ksSBFromSketch                =1          # from enum ksSketchBendBuildingTypeEnum
	ksSBSomeEdges                 =2          # from enum ksSketchBendBuildingTypeEnum
	ksRPBottomRight               =2          # from enum ksSpecRoughPlacementEnum
	ksRPTopLeft                   =0          # from enum ksSpecRoughPlacementEnum
	ksRPTopRight                  =1          # from enum ksSpecRoughPlacementEnum
	ksSHTByCurve                  =2          # from enum ksSpiral3DHeightTypeEnum
	ksSHTByObject                 =1          # from enum ksSpiral3DHeightTypeEnum
	ksSHTByValue                  =0          # from enum ksSpiral3DHeightTypeEnum
	ksSBTByStepAndHeight          =1          # from enum ksSpline3DBuildingTypeEnum
	ksSBTByStepAndTurnCount       =0          # from enum ksSpline3DBuildingTypeEnum
	ksSBTByTurnCountAndHeight     =2          # from enum ksSpline3DBuildingTypeEnum
	ksSDTByGeneratrixTiltAngle    =2          # from enum ksSpline3DDiameterTypeEnum
	ksSDTByObject                 =1          # from enum ksSpline3DDiameterTypeEnum
	ksSDTByValue                  =0          # from enum ksSpline3DDiameterTypeEnum
	ksSTByDirection               =1          # from enum ksSplineTangentEnum
	ksSTCurveU                    =2          # from enum ksSplineTangentEnum
	ksSTCurveV                    =3          # from enum ksSplineTangentEnum
	ksSTNone                      =0          # from enum ksSplineTangentEnum
	ksSTSurfaceCurve              =4          # from enum ksSplineTangentEnum
	ksSTTByParam                  =1          # from enum ksSplineTransitionTypeEnum
	ksSTTConstraint               =2          # from enum ksSplineTransitionTypeEnum
	ksSTTNone                     =0          # from enum ksSplineTransitionTypeEnum
	ksCollisionStep               =16         # from enum ksStepTypeEnum
	ksDeviationStep               =2          # from enum ksStepTypeEnum
	ksMetricStep                  =4          # from enum ksStepTypeEnum
	ksMipStep                     =32         # from enum ksStepTypeEnum
	ksParamStep                   =8          # from enum ksStepTypeEnum
	ksSpaceStep                   =1          # from enum ksStepTypeEnum
	ksTEFGeometryOnly             =1          # from enum ksTextExportFormEnum
	ksTEFTextOnly                 =0          # from enum ksTextExportFormEnum
	ksBaseProperties              =-1         # from enum ksTextureTypeEnum
	ksCutting                     =2          # from enum ksTextureTypeEnum
	ksRelief                      =1          # from enum ksTextureTypeEnum
	ksTexture                     =0          # from enum ksTextureTypeEnum
	ksTRCoefficient               =4          # from enum ksToleranceRecalcsEnum
	ksTRLowerLimit                =1          # from enum ksToleranceRecalcsEnum
	ksTRMiddle                    =3          # from enum ksToleranceRecalcsEnum
	ksTRTopLimit                  =2          # from enum ksToleranceRecalcsEnum
	ksTRUnknown                   =0          # from enum ksToleranceRecalcsEnum
	ksTRUser                      =5          # from enum ksToleranceRecalcsEnum
	ksTVBNormal                   =2          # from enum ksTransitionVectorIndexEnum
	ksTVNormal                    =1          # from enum ksTransitionVectorIndexEnum
	ksTVTangent                   =0          # from enum ksTransitionVectorIndexEnum
	ksUCDictanceAll               =2          # from enum ksUndercutDistanceTypeEnum
	ksUCDictanceIn                =1          # from enum ksUndercutDistanceTypeEnum
	ksUCDictanceOut               =0          # from enum ksUndercutDistanceTypeEnum
	ksCoefficient                 =0          # from enum ksUnfoldTypeEnum
	ksDecreaseBend                =2          # from enum ksUnfoldTypeEnum
	ksTableBends                  =3          # from enum ksUnfoldTypeEnum
	ksValueBend                   =1          # from enum ksUnfoldTypeEnum
	ksVector3D2Angles             =5          # from enum ksVector3DParametersTypeEnum
	ksVector3D2Vertex             =1          # from enum ksVector3DParametersTypeEnum
	ksVector3DAxis                =3          # from enum ksVector3DParametersTypeEnum
	ksVector3DCSAngle             =2          # from enum ksVector3DParametersTypeEnum
	ksVector3DCoefficients        =4          # from enum ksVector3DParametersTypeEnum
	ksVector3DCurve               =9          # from enum ksVector3DParametersTypeEnum
	ksVector3DEdge                =6          # from enum ksVector3DParametersTypeEnum
	ksVector3DPlane               =7          # from enum ksVector3DParametersTypeEnum
	ksVector3DScreen              =10         # from enum ksVector3DParametersTypeEnum
	ksVector3DSurface             =8          # from enum ksVector3DParametersTypeEnum
	ksVector3DUnknown             =0          # from enum ksVector3DParametersTypeEnum
	ksVPSUnknown                  =-1         # from enum ksViewProjectionScheme
	ksVPSUser                     =0          # from enum ksViewProjectionScheme
	ksVPSX90AxonometricISO        =6          # from enum ksViewProjectionScheme
	ksVPSXAxonometric             =3          # from enum ksViewProjectionScheme
	ksVPSY90AxonometricISO        =5          # from enum ksViewProjectionScheme
	ksVPSYAxonometric             =2          # from enum ksViewProjectionScheme
	ksVPSZ90AxonometricISO        =4          # from enum ksViewProjectionScheme
	ksVPSZAxonometric             =1          # from enum ksViewProjectionScheme
	ksVPDimetric                  =8          # from enum ksViewProjectionType
	ksVPDown                      =4          # from enum ksViewProjectionType
	ksVPFront                     =1          # from enum ksViewProjectionType
	ksVPIsometric                 =7          # from enum ksViewProjectionType
	ksVPLeft                      =5          # from enum ksViewProjectionType
	ksVPNone                      =-1         # from enum ksViewProjectionType
	ksVPNormalTo                  =0          # from enum ksViewProjectionType
	ksVPRear                      =2          # from enum ksViewProjectionType
	ksVPRight                     =6          # from enum ksViewProjectionType
	ksVPUnfold                    =9          # from enum ksViewProjectionType
	ksVPUp                        =3          # from enum ksViewProjectionType
	ksVPUser                      =10         # from enum ksViewProjectionType
	ksVSByLayer                   =2          # from enum ksVisibleStateEnum
	ksVSHidden                    =1          # from enum ksVisibleStateEnum
	ksVSUndefined                 =-1         # from enum ksVisibleStateEnum
	ksVSVisible                   =0          # from enum ksVisibleStateEnum
	ksZoneDivisionByPlanes        =1          # from enum ksZoneDivisionTypeEnum
	ksZoneDivisionRegular         =0          # from enum ksZoneDivisionTypeEnum
	ksZoneByObjects               =2          # from enum ksZoneTypeEnum
	ksZoneByPoints                =1          # from enum ksZoneTypeEnum
	ksZoneFree                    =0          # from enum ksZoneTypeEnum

RecordMap = {
}

CLSIDToClassMap = {
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
}


NamesToIIDMap = {
}

win32com.client.constants.__dicts__.append(constants.__dict__)

